# Final version of calls used for data in paper
# last modified: 2010-09-13
#  note that this will take some time to run and the output
#  used in the paper is provided in the data/ directory of
#  electronic supplement 2.

#  to run this script set PATH to the location of the
#  directory holding the unzipped electronic supplement 2
#  note that the path should be terminated with a '/'
PATH <- '/'

# load the R function 'lop'
source(paste(PATH, 'Rfunctions/lop.R', sep = ''))

# Model a basic 9 by 11 pixel landscape, at different csizes
run22list <- vector(mode = 'list', length = 10)
css <- c(1,2,3,4,5,7,10,15,25,50)
for (ii in 1:10){
  run22list[[ii]] <- lop(30, nt = 1000, csize = css[ii],
                         rt = FALSE,
                         xti = seq(0.1, 0.9, by = 0.1),
                         lambda = seq(0, 1, by = 0.1),
                         xtt = 'rpoint', draw = FALSE)
  dput(run22list, 'run22list.Rdput')
  cat('\n', ii, '\n', sep = '')
}            
dput(run22list, 'run22list.Rdput')

# Model transects across landscape with fixed lambda
run23 <- lop(30, nt = 1000, rt = FALSE,
            xti = seq(0.01, 0.99, by = 0.01),
            lambda = c(0.1, 0.5, 0.9), xtt = 'rpoint',
            draw = FALSE)
dput(run23, 'run23.Rdput')

# Model transects across landscape with fixed xti
run24 <- lop(30, nt = 1000, rt = FALSE,
            xti = c(0.1, 0.5, 0.9),
            lambda = seq(0, 1, by = 0.01), xtt = 'rpoint',
            draw = FALSE)
dput(run24, 'run24.Rdput')

# Model sensitivity to tree size
run25list <- vector(length = 25, mode = 'list')
treesizes <- c(5:10, seq(20, 100, by = 10),
                     seq(200, 1000, by = 100), 5000)
for(i in 1:25){
  run25list[[i]] <- lop(30, nt = treesizes[i],
                        xti = c(0.1, 0.5, 0.9),
                        dim = 1, lambda = (0, 0.1, 0.5, 0.9, 1),
                        xtt = 'rpoint',
                        draw = FALSE)
}
dput(run25list, 'run25list.Rdput')

# Model sensitivity to dimensionality
run26list <- vector(length = 10, mode = 'list')
dims <- c(1, 2, 5, 10, 20, 50, 100, 200, 500, 1000)
for(i in 1:10){	
  run26list[[i]] <- lop(30, nt = 1000, xti = c(0.1, 0.5, 0.9),
                       dim = dims[i],
                       lambda = (0, 0.1, 0.5, 0.9, 1),
                       xtt = 'top',
                       draw = FALSE)
}
dput(run26list, 'run26list.Rdput')