# Final R script for producing figures used in paper
# begun: 09-06-04
# last modified: 10-09-13

#  to run this script set PATH to the location of the
#  directory holding the unzipped electronic supplement 2
#  note that the path should NOT be terminated with a '/'
PATH <- ''

########## FIGURE 3A,B,C ##########

run22list <- dget(paste(PATH, 'data/run22list.Rdput', sep = '/'))
run23 <- dget(paste(PATH, 'data/run23.Rdput', sep = '/'))
run24 <- dget(paste(PATH, 'data/run24.Rdput', sep = '/'))

quartz(width = 8, height = 6)
par(mfrow = c(2,2))
plotme <- apply(run22list[[1]]$mean.ext.sizes, c(2,3), mean)
ymax <- max(plotme)
image(plotme,
      xaxt = 'n', yaxt = 'n', xlab = '',
      ylab='', main = expression('Mean extinct clade size'),
      sub = '1 ecological dimension',
	  col = grey(seq(1, 0, length.out = 12)))
mtext(side = 1, expression(lambda), line = 2)
mtext(side = 2, 'xti', font = 3, line = 2)
mtext('mean of 30 trees with 1000 terminals')
axis(1, at=seq(0,1,0.1))
axis(2, at=seq(0,1,length.out=9),
     labels=seq(0.1,0.9,0.1))
abline(h = 0, lwd = 2)
abline(h = 0.5, lwd = 2)
abline(h = 1, lwd = 2)
abline(v = 0.1, lwd = 2)
abline(v = 0.5, lwd = 2)
abline(v = 0.9, lwd = 2)
###
plotme <- apply(run24$mean.ext.sizes, c(2,3), mean)
plot(seq(0, 1, by = 0.01), plotme[,1],
     main = expression(paste('Varying ', lambda, ' at fixed extinction intensity')),
     ylim = c(0,ymax), type = 'l',
     xlab = '', ylab = 'mean extinct clade size')
mtext(side = 1, expression(lambda), line = 2)
lines(seq(0, 1, by = 0.01), plotme[,2])
lines(seq(0, 1, by = 0.01), plotme[,3])
text(0.2, 0.6, 'xti=', font = 3, cex = 0.7)
text(0.26, 0.6, '0.1', cex = 0.7)
text(0.4, 1.8, 'xti=', font = 3, cex = 0.7)
text(0.46, 1.8, '0.5', cex = 0.7)
text(0.6, 4.8, 'xti=', font = 3, cex = 0.7)
text(0.66, 4.8, '0.9', cex = 0.7)
###
plotme <- apply(run23$mean.ext.sizes, c(2,3), mean)
plot(seq(0.01, 0.99, by = 0.01), plotme[1,],
     main = expression(paste('Varying extinction intensity at fixed ', lambda)),
     ylim = c(0,ymax), type = 'l',
     xlab = '', ylab = 'mean extinct clade size')
mtext(side = 1, 'xti', font = 3, line = 2)
lines(seq(0.01, 0.99, by = 0.01), plotme[2,])
lines(seq(0.01, 0.99, by = 0.01), plotme[3,])
text(0.2, 0.6, expression(paste(lambda, '=')), cex = 0.7)
text(0.25, 0.6, '0.1', cex = 0.7)
text(0.8, 3.3, expression(paste(lambda, '=')), cex = 0.7)
text(0.85, 3.3, '0.5', cex = 0.7)
text(0.5, 2.5, expression(paste(lambda, '=')), cex = 0.7)
text(0.55, 2.5, '0.9', cex = 0.7)

#see prior version for non-working lattice version of 3A--C
#  and NAPC talk figure

# figure 3D
library(lattice)
quartz(width = 4, height = 3)
plotme <- apply(run22list[[1]]$mean.ext.sizes,
                c(2,3), mean)
wireframe(plotme, drape = TRUE,
          xlab = expression(paste('coherence(', lambda, ')')),
          ylab='extinction\nintensity (xti)',
          zlab = 'mean\nextinct\nclade\nsize',
          col.regions = grey(seq(1, 0, length.out = 200)))

########## FIGURE 4 ##########
quartz(height = 10, width = 3)
par(mfrow = c(4,1))

for(ii in c(1,5,7,10)){
  plotme <- apply(run22list[[ii]]$csizes.p, c(2,3), sum) /
            apply(run22list[[ii]]$csizes.t, c(2,3), sum)
  image(plotme,
        xaxt = 'n', yaxt = 'n', xlab = '', ylab='',
        main = paste('Proportion of extinct clades of size',
                     run22list[[ii]]$param[4]),
	  col = grey(seq(1, 0, length.out = 12)))
  if(ii == 1){
    mtext(side = 3, 'mean of 30 trees with 1000 terminals',
          cex = 0.7)
    mtext(side = 1, '1 ecological dimension', line = 3, cex = 0.7)
  }
  mtext(side = 2, 'xti', font = 3, line = 2)
  mtext(side = 1, expression(lambda), line = 2)
  axis(1, at=seq(0,1,0.1))
  axis(2, at=seq(0,1,length.out=9),
       labels=seq(0.1,0.9,0.1))
}

#see prior version for non-working lattice version of 4

########## FIGURE 5 ##########
run25list <- dget(paste(PATH, 'data/run25list.Rdput', sep = '/'))
treesizes <- c(5:10, seq(20, 100, by = 10),
                     seq(200, 1000, by = 100), 5000)
                     
quartz(width = 8, height = 10)
#str(run25list[[1]]$mean.ext.sizes)
par(mfrow = c(2,1))
foo <- function(x){as.vector(x$mean.ext.sizes[,3,2])}
plot(rep(treesizes, each = 30), unlist(lapply(run25list, foo)),
        main = expression('Sensitivity to tree size; 30 trees, 1 dimension, ' * italic('xti') * '=0.5'),
        xlab = 'number of terminals',
        ylab = 'mean size of extinct clades',
        xlim = c(3, 5000),
        xaxt = 'n',
        log = 'x', pch = 5, cex = 0.5)
axis(1, at = treesizes, las = 3, cex.axis = 0.7)
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lwd = 2)
mtext(expression(paste('points shown only for ',
      lambda, '=0.5')))
text(4, model$y[1],
     expression(paste(lambda, '=0.5')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,2,2])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(paste(lambda, '=0.1')),
     adj = c(1,1), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,1,2])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(paste(lambda, '=0')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,4,2])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(paste(lambda, '=0.9')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,5,2])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(paste(lambda, '=1')),
     adj = c(1,0.5), cex = 0.7)
###
foo <- function(x){as.vector(x$mean.ext.sizes[,3,2])}
plot(rep(treesizes, each = 30), unlist(lapply(run25list, foo)),
        main = expression(paste('Sensitivity to tree size; 30 trees, 1 dimension, ', lambda, '=0.5')),
        xlab = 'number of terminals',
        xlim = c(3, 5000),
        ylab = 'mean size of extinct clades', xaxt = 'n',
        log = 'x', pch = 5, cex = 0.5)
axis(1, at = treesizes, las = 3, cex.axis = 0.7)
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lwd = 2)
mtext(expression('points shown only for ' * italic('xti') * '=0.5'))
text(4, model$y[1],
     expression(italic('xti') * '=0.5'),
     adj = c(1,0.5), cex = 0.7, font = 3)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,3,1])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(italic('xti') * '=0.1'),
     adj = c(1,0.5), cex = 0.7, font = 3)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,3,3])} 
model <- lowess(rep(treesizes, each = 30),
                unlist(lapply(run25list, foo)))
lines(model, lty = 2)
text(4, model$y[1],
     expression(italic('xti') * '=0.9'),
     adj = c(1,0.5), cex = 0.7, font = 3)

########## FIGURE 6 ##########
run26list <- dget(paste(PATH, 'data/run26list.Rdput', sep = '/'))
dims <- c(1, 2, 5, 10, 20, 50, 100, 200, 500, 1000)
#str(run26list[[1]]$mean.ext.sizes)

quartz(width = 8, height = 10)
par(mfrow = c(2,1))
foo <- function(x){as.vector(x$mean.ext.sizes[,3,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
plot(rep(dims, each = 30), unlist(lapply(run26list, foo)),
        main = expression('Sensitivity to dimensionality; 30 trees, 1000 terminals, ' * italic('xti') * '=0.5'),
        xlab = 'number of dimensions',
        xlim = c(0.5, 1000), ylim = c(1,4),
        ylab = 'mean size of extinct clades', xaxt = 'n',
        log = 'x', pch = 5, cex = 0.5)
axis(1, at = dims, las = 3, cex.axis = 0.7)
lines(model, lwd = 2)
mtext(expression(paste('points shown only for ', lambda, '=0.5')))
text(0.8, model$y[1],
     expression(paste(lambda, '=0.5')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,1,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(paste(lambda, '=0.1')),
     adj = c(1,0.8), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,2,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(paste(lambda, '=0')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,4,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(paste(lambda, '=0.9')),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,5,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(paste(lambda, '=1')),
     adj = c(1,0.5), cex = 0.7)
###
foo <- function(x){as.vector(x$mean.ext.sizes[,3,2])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
plot(rep(dims, each = 30), unlist(lapply(run26list, foo)),
        main = expression(paste('Sensitivity to dimensionality; 30 trees, 1000 terminals, ', lambda, '=0.5')),
        xlab = 'number of dimensions',
        xlim = c(0.5, 1000), ylim = c(1,4),
        ylab = 'mean size of extinct clades', xaxt = 'n',
        log = 'x', pch = 5, cex = 0.5)
axis(1, at = dims, las = 3, cex.axis = 0.7)
lines(model, lwd = 2)
mtext(expression('points shown only for ' * italic('xti') * '=0.5'))
text(0.8, model$y[1],
     expression(italic('xti') * '=0.5'),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,3,1])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(italic('xti') * '=0.1'),
     adj = c(1,0.5), cex = 0.7)
#
foo <- function(x){as.vector(x$mean.ext.sizes[,3,3])}
model <- lowess(rep(dims, each = 30),
                unlist(lapply(run26list, foo)))
lines(model, lty = 2)
text(0.8, model$y[1],
     expression(italic('xti') * '=0.9'),
     adj = c(1,0.5), cex = 0.7)

########## FIGURE 7 ##########
lh <- read.table(paste(PATH, 'data/lambda_hat.csv', sep = '/'),
                   sep = '\t', header = TRUE)

eo_tot_reps <- rowSums(lh[,c(2,4,6,8,10,12,14)], na.rm = TRUE)
ws_tot_reps <- rowSums(lh[,c(16,18)], na.rm = TRUE)

eo_tot_hits <- rowSums(lh[,c(3,5,7,9,11,13,15)], na.rm = TRUE)
ws_tot_hits <- rowSums(lh[,c(17,19)], na.rm = TRUE)

eo <- eo_tot_hits/eo_tot_reps
ws <- ws_tot_hits/ws_tot_reps

eo[is.nan(eo)] <- NA
ws[is.nan(ws)] <- NA

quartz(width = 6, height = 6)
plot(lh$lambda[!is.na(eo)], log(eo)[!is.na(eo)],
     type = 'l', ylim = c(-12, -4),
     ylab = 'Log likelihood',
     xlab = expression(lambda), cex.axis = 0.7,
     main = expression(paste('Estimating ', lambda,
                             ' for extinction susceptibility')))
lines(lh$lambda[!is.na(ws)], log(ws)[!is.na(ws)])
#eo.0 <- eo
#eo.0[is.na(eo.0)] <- 0.0000001
eo.low <- lowess(log(eo)[!is.na(eo)] ~ lh$lambda[!is.na(eo)],
      f = 0.2)
lines(eo.low, lty = 3)
ws.log <- log(ws)
ws.log[is.infinite(ws.log)] <- 0
ws.low <- lowess(ws.log[!is.na(ws)] ~ lh$lambda[!is.na(ws)],
                 f = 0.35)
lines(ws.low$x, ws.low$y, lty = 3)

segments(0.97, -13, 0.97, -4.63, lty = 3)
segments(0.7, -13, 0.7, -9.4, lty = 3)
text(0.79, -4.4, 'Eocene/Oligocene Forams')
text(0.55, -9.1, 'Westphalian/Stephanian Plants')
axis(1, at = c(0.7, 0.97), labels = c(0.7, 0.97), las = 3)

# Maximum likelihood point estimates:
cat('x','y')
cat(eo.low$x[eo.low$y == max(eo.low$y)], max(eo.low$y))
cat(ws.low$x[ws.low$y == max(ws.low$y)], max(ws.low$y))

# ML confidence intervals: 1 or 2 log-likelihood units
#  (upper limit in all cases is 1)
eo.low$x[abs(eo.low$y - (max(eo.low$y) - 1)) ==
       min(abs(eo.low$y - (max(eo.low$y) - 1)))]

eo.low$x[abs(eo.low$y - (max(eo.low$y) - 2)) ==
       min(abs(eo.low$y - (max(eo.low$y) - 2)))]

ws.low$x[abs(ws.low$y - (max(ws.low$y) - 1)) ==
       min(abs(ws.low$y - (max(ws.low$y) - 1)))]

ws.low$x[abs(ws.low$y - (max(ws.low$y) - 2)) ==
       min(abs(ws.low$y - (max(ws.low$y) - 2)))]

# (Function for Figs. 8 and 9)
myAxisPhylo <- function (side = 1, at = NULL, labels = NULL, ...) 
{
    lastPP <- get("last_plot.phylo", envir = .PlotPhyloEnv)
    if (lastPP$type %in% c("phylogram", "cladogram")) {
        if (lastPP$direction %in% c("rightwards", "leftwards")) {
            x <- pretty(lastPP$xx)
            if (lastPP$direction == "rightwards") 
                maxi <- max(lastPP$xx)
            else {
                maxi <- min(lastPP$xx)
                x <- -x
            }
        }
        else {
            x <- pretty(lastPP$yy)
            if (lastPP$direction == "upwards") 
                maxi <- max(lastPP$yy)
            else {
                maxi <- min(lastPP$yy)
                x <- -x
            }
        }
    }
    if(is.null(at)){
    	if(is.null(labels)) labels <- abs(x)
    	at <- maxi - x
    }else{
    	if(is.null(labels)) labels <- paste(at)
    	at <- maxi - at
    }
    axis(side = side, at = at, labels = labels, ...)
}

########## FIGURE 8 ##########
#O/M 23.8	-9.9
#E/O 33.7	0
#P/E 54.8	21.1
#K/T 65.0	31.3
#J/K 142.0	108.3
require(ape)
eo.tr <- read.tree(paste(PATH, 'data/EO.scaled.nwk', sep = '/'))

eo.dat <- read.table(paste(PATH, 'data/EOdata.csv', sep = '/'),
                     sep = '\t', header = TRUE)

# MISTAKE IN PRELIMINARY FIGURES
# Need to figure out how to reorder victimhood for plotting....
##########
# from R-help
# From: Wolfram Fischer <wolfram_at_fischer-zim.ch> 
# Date: Tue 05 Oct 2004 - 00:21:14 EST
###
#d <- sample(10:100, 9)
#o <- order(d)
#r <- d[o]
#r[order(o)]
##########
#dd <- c('a', 'l', 'r', 'b', 'c', 'p', 'z', 'e', 'q')
#oo <- order(dd)
#rr <- dd[oo]
#rr[order(oo)]
###
#dt <- ploteo.tr$tip.label
#ot <- order(dt)
#rt <- dt[ot]
#rt[order(ot)]
###
#unordered_vector <- sample(1:10)
#unordered_vector
#vector_order <- order(unordered_vector)
#vector_order
#ordered_vector <- unordered_vector[vector_order]
#ordered_vector
#identical(unordered_vector, ordered_vector[order(vector_order)])
##########

tips <- ploteo.tr$tip.label
tip.order <- order(tips)
tips.alpha <- tips[tip.order]

identical(tips, tips.alpha[order(tip.order)])

foo <- cbind(eo.dat[order(eo.dat$TAXON_CODE),], tips.alpha = ploteo.tr$tip.label[order(ploteo.tr$tip.label)])

vict.alpha <- foo$SURV_VICT
dim.alpha <- foo$MAX_DIM

vict.reorder <- vict.alpha[order(tip.order)]
dim.reorder <- dim.alpha[order(tip.order)]

cbind(vict.reorder, dim.reorder, ploteo.tr$tip.label)

quartz(width = 6, height = 8)
par(xpd = NA, mar = c(5,2,4,0))
ploteo.tr <- eo.tr
ploteo.tr$tip.label <- gsub('.', ' ', ploteo.tr$tip.label,
                            fixed = TRUE)
plot(ploteo.tr, use.edge.length = TRUE,
     label.offset = 6, cex = 0.6,
     main = 'Foraminifera at E/O boundary')
# arg 'main' not working in plot.phylo(){ape v. 2.5}
text(105, 52, 'Foraminefera at E/O boundary')
text(105, 50, 'solid = extinct', cex = 0.8)
myAxisPhylo(at = c(0, 16.3, 66.3, 116.3), cex.axis = 0.7,
            labels = c(33.7, 50, 100, 150), line = 2)
#myAxisPhylo(at = c(-9.9, 0, 21.1, 31.3, 108.3),
#            labels = c('O/M','E/O', 'P/E', 'K/T', 'J/K'),
#            cex.axis = 0.6)
tiplabels(cex = dim.reorder * 4, pch = 21,
          col = 'black',
          bg = as.numeric(vict.reorder) - 1, lwd = 1)
text(155, 49.5, 'Maximum Dimension (mm)', srt = 45, cex = 0.5)
text(150, -6.3, 'Ma')
#
rect(-50, -3.94, 26.5, -2)
text(0, -3, 'Jurassic', cex = 0.6)
#
rect(26.5, -3.94, 105, -2, col = 'black')
text(65, -3, 'Cretaceous', col = 'white', cex = 0.6)
#
rect(105, -3.94, 115, -2)
text(110, -3, 'Pal.', cex = 0.6)
#
rect(115, -3.94, 136, -2, col = 'black')
text(125, -3, 'Eocene', col = 'white', cex = 0.6)
#
rect(136, -3.94, 250, -2)
text(150, -3.1, 'Oligocene', cex = 0.6)

########## FIGURE 9 ##########
#C/P 292	-11
#W/S 303	0
#M/P 323	20
#D/C 354	51
#S/D 417	114
ws.tr <- read.tree(paste(PATH, 'data/WS.scaled.nwk', sep = '/'))

ws.dat <- read.table(paste(PATH, 'data/WSdata.csv', sep = '/'),
                     sep = '\t', header = TRUE)

# Create ecological variables
vol <- (4 / 3) * pi * (ws.dat$DIASPORE_L / 2) *
                      (ws.dat$DIASPORE_W / 2) *
                      (ws.dat$DIASPORE_D / 2)
sta <- ws.dat$STATURE

#vol[is.na(vol)] <- 0
#vol[vol == 0] <- min(vol[vol > 0], na.rm = TRUE) / 100
vol[vol == 0] <- min(vol[vol > 0], na.rm = TRUE) * 0.9
lvol <- log10(vol)
vptsize <- 0.1 + 2 * (lvol + max(abs(lvol), na.rm = TRUE)) /
           max(lvol + max(abs(lvol), na.rm = TRUE), na.rm = TRUE)
vict <- ws.dat$STEPH_X

# Does not need reordering, but check that data is in same order as
#  tree tip labels:
cbind(ws.dat, ws.tr$tip.label)

quartz(width = 6, height = 8)
par(xpd = NA, mar = c(5,2,4,0))
plotws.tr <- ws.tr
plotws.tr$tip.label <- as.character(ws.dat$TAXON)
plot(plotws.tr, use.edge.length = TRUE,
     label.offset = 12, cex = 0.6,
     main = 'Land plants at W/S boundary')
# arg 'main' not working in plot.phylo(){ape v. 2.5}
text(90, 61, 'Land plants at W/S boundary')
text(90, 58.5, 'solid = extinct', cex = 0.8)
myAxisPhylo(at = c(0, 47, 97), cex.axis = 0.7,
            labels = c(303, 350, 400), line = 2)
#myAxisPhylo(at = c(-11, 0, 20, 51, 114),
#            labels = c('C/P', 'W/S', 'M/P', 'D/C', 'S/D'),
#            cex.axis = 0.6)
tiplabels(pch = 21, cex = (sta/4) + 0.5,
          bg = vict, lwd = 1,
          adj = c(0.5, 0.5))
tiplabels(pch = 21, bg = vict, lwd = 1,
          cex = vptsize,
          adj = c(8, 0.5))
text(118, 56, 'Stature', srt = 45, cex = 0.5)
text(133, 57.3, expression(paste('Seed Size (', mm^3, ')')),
     srt = 45, cex = 0.5)
text(135, -7.65, 'Ma')
#
rect(-50, -4.8, 0.5, -2.5)
text(-10, -3.5, 'Silurian', cex = 0.6)
#
rect(0.5, -4.8, 63.2, -2.5, col = 'black')
text(33, -3.5, 'Devonian', col = 'white', cex = 0.6)
#
rect(63.2, -4.8, 94.3, -2.5)
text(80, -3.5, 'Miss.', cex = 0.6)
#
rect(94.3, -4.8, 125.2, -2.5, col = 'black')
text(111, -3.5, 'Penn.', col = 'white', cex = 0.6)
#
rect(125.2, -4.8, 250, -2.5)
text(140, -3.5, 'Permian', cex = 0.6)

########## FIGURE 10 ##########

vict <- as.numeric(ws.dat$STEPH_X)
jit <- log10(runif(length(vol)))

quartz(width = 6, height = 6)
par(mar = c(5,8,8,2))
plot(lvol + jit, jitter(sta), pch = 23, bg = vict,
     main = 'W/S land plant extinctions',
     xlab = expression('Disseminule volume (' * mm^3* ')'),
     ylab = '', yaxt = 'n', xaxt = 'n',
     ylim = c(0.8,4.3), xlim = c(-7, 7))
mtext('solid = extinct at W/S boundary')
mtext(side = 2, 'Plant stature', line = 4)
axis(2, at = c(1,2,3,4), labels = c('Herb', 'Shrub',
     'Small tree', 'Large tree'), las = 2, cex.axis = 0.8)
xvals <- c(-6, -3, 0, 3, 6)
axis(1, at = xvals, labels = 10^xvals)
points(lvol + jit, jitter(rep(6, length(vol))),
       pch = 23, bg = vict, xpd = NA)
pval <- format(cor.test(vol[!vict], sta[!vict],
               alternative = 'two')$p.value,
               digits = 2)
mtext(side = 4, bquote('among survivors, correlation=0 with '
                       * italic('p') * '=' * .(pval)))
#mtext(side = 4, paste('correlation zero with p =',
#                      format(cor.test(vol, sta,
#                      alternative = 'two')$p.value,
#                      digits = 2)))

#plot(log(vol), sta)
#abline(lm(log(vol) ~ sta), col = 'red')
#abline(lm(sta ~ log(vol)), col = 'blue')
#library(quantreg)
#abline(rq(log(vol) ~ sta), col = 'green')
#abline(rq(sta ~ log(vol)), col = 'black')

########## FIGURE 11 ##########
eo.t <- t.test(eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'S'], 
               eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'V'])
ws.vol.t <- t.test(vol[ws.dat$STEPH_X == 1],
                   vol[ws.dat$STEPH_X == 0])
ws.sta.t <- t.test(sta[ws.dat$STEPH_X == 1],
                   sta[ws.dat$STEPH_X == 0])
                   
eo.mw <- wilcox.test(eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'S'], 
               eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'V'])
ws.vol.mw <- wilcox.test(vol[ws.dat$STEPH_X == 1],
                   vol[ws.dat$STEPH_X == 0])
ws.sta.mw <- wilcox.test(sta[ws.dat$STEPH_X == 1],
                   sta[ws.dat$STEPH_X == 0])

quartz(width = 9, height = 4)
par(mfrow = c(1,3))
boxplot(list(Surv. = eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'S'],
             Vict. = eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'V']),
             col = c(0,1), varwidth = TRUE,
             main = 'E/O Forams extinctions by size',
             ylab = 'Max. dimension (mm)',
             xlim = c(0,3),
             medlwd = 1, medpch = 19, medcex = 1.5,
             medcol = c('black', 'white'))
stripchart(list(Surv. = eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'S'],
             Vict. = eo.dat$MAX_DIM[eo.dat$SURV_VICT == 'V']),
             add = TRUE, vertical = TRUE, pch = 21,
             col = grey(0.4), cex = 1,
             method = 'stack')
mtext(paste('t-test p=',
            format(eo.t$p.value, digits = 2),
            ', wilcoxon p=',
            format(eo.mw$p.value, digits = 2), sep = ''))
boxplot(list(Surv. = log(vol[ws.dat$STEPH_X == 0]),
             Vict. = log(vol[ws.dat$STEPH_X == 1])),
             col = c(0,1), varwidth = TRUE,
             main = 'W/S Plant extinctions by seed size',
             ylab = 'Log seed volume (cubic mm)',
             xlim = c(0,3),
             medlwd = 1, medpch = 19, medcex = 1.5,
             medcol = c('black', 'white'))
stripchart(list(Surv. = log(vol[ws.dat$STEPH_X == 0]),
                Vict. = log(vol[ws.dat$STEPH_X == 1])),
           add = TRUE, vertical = TRUE, pch = 21,
           col = grey(0.4), cex = 1,
           method = 'stack')
mtext(paste('t-test p=',
            format(ws.vol.t$p.value, digits = 2),
            ', wilcoxon p=',
            format(ws.vol.mw$p.value, digits = 2), sep = ''))
boxplot(list(Surv. = sta[ws.dat$STEPH_X == 0],
             Vict. = sta[ws.dat$STEPH_X == 1]),
             col = c(0,1), varwidth = TRUE,
             main = 'W/S Plant extinctions by stature',
             ylab = 'Adult Stature (1=herb; 4=tree)',
             xlim = c(0,3),
             medlwd = 1, medpch = 19, medcex = 1.5,
             medcol = c('black', 'white'))
stripchart(list(Surv. = sta[ws.dat$STEPH_X == 0],
                Vict. = sta[ws.dat$STEPH_X == 1]),
           add = TRUE, vertical = TRUE, pch = 21,
           col = grey(0.4), cex = 1,
           method = 'stack')
mtext(paste('t-test p=',
            format(ws.sta.t$p.value, digits = 2),
            ', wilcoxon p=',
            format(ws.sta.mw$p.value, digits = 2), sep = ''))

############################################################
############################################################
# calculating statistics...

# drop tips from ws tree for missing volume measurements
ws.drop.tr <- drop.tip(ws.tr,
                       tip = ws.dat$TAXON_CODE[is.na(vol)])

#vol[is.na(vol)] <- 0
#lvol[is.na(lvol)] <- 0
names(vol) <- ws.dat$TAXON_CODE
names(lvol) <- ws.dat$TAXON_CODE

# Calculating Pagel's lambda
library(geiger)
paste('eo--max dimension lambda =',
      fitContinuous(eo.tr, log10(eo.dat$MAX_DIM),
                    model = 'lambda')$Trait1$lambda)
#paste('ws--volume lambda =',
#      fitContinuous(ws.tr, vol,
#                    model = 'lambda')$Trait1$lambda)
#paste('ws--volume lambda =',
#      fitContinuous(ws.tr, lvol,
#                    model = 'lambda')$Trait1$lambda)
paste('ws--stature lambda =',
      fitContinuous(ws.tr, sta,
                    model = 'lambda')$Trait1$lambda)
paste('ws--volume lambda =',
      fitContinuous(ws.drop.tr, lvol,
                    model = 'lambda')$Trait1$lambda)

#[1] "eo--max dimension lambda = 0.97308956890314"
#[1] "ws--stature lambda = 1"
#[1] "ws--volume lambda = 0.988620856609768"

# Calculating Blomberg's K
library(picante)
#paste('eo--max dimension K =', Kcalc(eo.dat$MAX_DIM, eo.tr))
paste('eo--max dimension K =', Kcalc(log10(eo.dat$MAX_DIM),
      eo.tr))
#paste('ws--volume K =', Kcalc(vol, ws.tr))
paste('ws--volume K =', Kcalc(na.omit(lvol), ws.drop.tr))
paste('ws--stature K =', Kcalc(sta, ws.tr))

#[1] "eo--max dimension K = 0.381732527263032"
#[1] "ws--volume K = 0.89098987856365"
#[1] "ws--stature K = 0.539948399807468"

#eo.tr.dichot <- multi2di(eo.tr)
#ws.tr.dichot <- multi2di(ws.tr)
#phylosignal(eo.dat$MAX_DI, eo.tr.dichot)
#phylosignal(vol, ws.tr.dichot)
#phylosignal(sta, ws.tr.dichot)

# Rerunning model with observed values
source(paste(PATH,'Rfunctions/lop.R', sep = '/'))
eo.mod <- lop(30, nt = 46, xti = 0.37, dim = 1, lambda = 0.97,
              xtt = 'top', draw = FALSE)
mean(eo.mod$mean.ext.size)
#[1] 1.935784

#ws.mod <- lop(30, nt = 54, xti = 0.65, dim = 1,
#              lambda = c(0.0053, 1),
#              xtt = 'top', draw = FALSE)
#mean(ws.mod$mean.ext.size[,1,1])
#[1] 1.516816
#mean(ws.mod$mean.ext.size[,2,1])
#[1] 3.212757

ws.sta <- lop(30, nt = 54, xti = 0.65, dim = 1,
              lambda = 1,
              xtt = 'top', draw = FALSE)
mean(ws.sta$mean.ext.size)
#[1] 3.010121

ws.vol <- lop(30, nt = 54, xti = 0.65, dim = 1,
              lambda = 0.99,
              xtt = 'top', draw = FALSE)
mean(ws.vol$mean.ext.size)
#[1] 2.906171

# Expected extinct clade size under binomial (nt, xti)
#  lambda = 0 model
# W-S
#54 * 0.65 * (1-0.65)
#46 * 0.37 * (1-0.37)
#qbinom(0.95, 54, 0.65)
#qbinom(0.95, 46, 0.37)

eo.null <- lop(30, nt = 46, xti = 0.37, dim = 1,
               lambda = 0,
               xtt = 'top', draw = FALSE)

mean(eo.null$mean.ext.sizes)
#[1] 1.216373

sd(eo.null$mean.ext.sizes)
#[1] 0.1211260

c(mean(eo.null$mean.ext.sizes) - sd(eo.null$mean.ext.sizes),
  mean(eo.null$mean.ext.sizes) + sd(eo.null$mean.ext.sizes))
#[1] 1.095247 1.337499

ws.null <- lop(30, nt = 54, xti = 0.65, dim = 1,
               lambda = 0,
               xtt = 'top', draw = FALSE)
               
mean(ws.null$mean.ext.sizes)
# [1] 1.472177

sd(ws.null$mean.ext.sizes)
#[1] 0.1727853

c(mean(ws.null$mean.ext.sizes) - sd(ws.null$mean.ext.sizes),
  mean(ws.null$mean.ext.sizes) + sd(ws.null$mean.ext.sizes))
#[1] 1.299392 1.644962