lop.tree <- function(phy, lambda = 0.5, xti = 0.37, dim = 1,
                     xtt = 'top', draw = TRUE, verbose = TRUE){
  tr<- phy
  nt<- length(tr$tip.label)

  VV <- vcv.phylo(tr)
  Lambda <- matrix(data = lambda, nrow = nt, ncol = nt)
  diag(Lambda) <- 1
   
  #create an ecological variable across dim dimensions
  ecoV <- mvrnorm(n = dim, mu = rep(0, times = nt),
                  Sigma = Lambda * VV)

  if (dim>1)	colnames(ecoV) <- tr$tip.label
  else			names(ecoV)<- tr$tip.label
  
  ne <- round(nt * xti)
    
  if(dim == 1){ # in the 1-dimensional case
    ecoV <- as.vector(ecoV)
    names(ecoV) <- tr$tip.label     
    if(xtt == 'center'){
      s.devs <- sort(abs(ecoV))
      dead.taxa <- names(s.devs[1:ne])
      #live.index <- !names(s.devs) %in% dead.taxa
      # WRONG - should take names from ecoV
      live.index <- !(names(ecoV) %in% dead.taxa)
    }else if(xtt == 'top'){
      s.devs <- sort(ecoV)
      dead.taxa <- names(s.devs[1:ne])
      live.index <- !names(ecoV) %in% dead.taxa    
    }else if(xtt == 'rand'){
      s.devs <- ecoV[sample(length(ecoV))]
      dead.taxa <- names(s.devs[1:ne])
      live.index <- !names(ecoV) %in% dead.taxa
    }else{
      stop('argument to xtt not understood')
    }
  }else{ # for >1-dimensional case
    if(xtt == 'center'){
      distfromcenter <- function(x){
        mean <- apply(ecoV, 1, mean)
    	as.numeric(dist(rbind(x,mean)))
      }
      s.devs <- sort(apply(ecoV, 2, distfromcenter))
      dead.taxa <- names(s.devs[1:ne])
      live.index <- !colnames(ecoV) %in% dead.taxa
    }else if(xtt == 'top'){
      distfromtop <- function(x){
        top <- apply(ecoV, 1, max)
        as.numeric(dist(rbind(x,top)))
      }
      s.devs <- sort(apply(ecoV, 2, distfromtop))
      dead.taxa <- names(s.devs[1:ne])
      live.index <- !colnames(ecoV) %in% dead.taxa    
    }else if(xtt == 'rand'){
      s.devs <- ecoV[sample(nt)]
      dead.taxa <- names(s.devs[1:ne])
      live.index <- !colnames(ecoV) %in% dead.taxa
    }else{
        stop('argument to xtt not understood')
    }
  }
  
  # measures of change
  all.sons <- get.all.sons(tr)
  dcs <- dead.clade.sizes(tr, dead.tips = dead.taxa)

  if(verbose){
    cat(paste('Extinction intensity: ', xti, '\n', sep = ''))
    cat(paste('Phylogenetic clumping (lambda): ',
              lambda, '\n', sep = ''))
    cat('Table of extinct clade sizes:')
    print(table(dcs$dead.distr))
    cat('==============================\n')
  }
  if(draw){
    plot(tr, label.offset=.2, cex=0.75)
	sv<- rep(0, times=nt)
	names(sv)<- tr$tip.label
	sv[dead.taxa]<- 1
    tiplabels(pch=21, bg=sv+1)
  }
return(dcs)
} # end of lop function
