## Re-written functions to compute tree branch lengths
# from ages of terminals, with options. Constraints on node
# ages as well.

############################################################
# Main wrapper
scalePhylo <- function(tr, tip.ages, node.mins=NULL,
                       min.diff=0.1){
  aa<- assign.ages(tr, tip.ages, node.mins, min.diff)
  trs<- assign.brlen(tr, aa)
  return(trs)	
}

############################################################
# Function to assign ages to internal nodes, given tree and
#   ages of terminal modes
#   --t1 is phylo (from package ape)
#   --ages is strat ages of terminal nodes
assign.ages <- function(tr, tip.ages, node.mins=NULL,
                        min.diff=0.1){
 ## do some error checking
 # makes sure tips have labels
 # check node labels?
 node.mins[is.na(node.mins)]<- -Inf		# so nodes with no information have no effect

 # change order of ages to match tip labels of t1
 oo<- charmatch(tr$tip.label, names(tip.ages))
 tip.ages<- tip.ages[oo]
 tn<- tr$edge
 max.term<- length(tr$tip.label)
 min.anc<- max.term+1
 max.anc<- min.anc + tr$Nnode -1
 aa<- array(dim=max(tn))   
 names(aa)<- as.character(1:max(tn))
 aa[1:max.term]<- tip.ages
 #print(aa)
 #print(node.mins)
 ii<- min.anc:max.anc

 # go through internal nodes, assign ages to them
 while (sum(is.na(aa))>=1)    # loop through as long as ages for some inodes not yet known
   {
      #print(aa)
      for (i in ii)
       {
          ci<- as.character(i)
          yy<- tn[,1]==i
          dec<- tn[,2][yy]              # direct descendants of i
          aad<- aa[as.character(dec)]   # ages of these direct descendants
          if (sum(is.na(aad))==0)       # if all ages are known.
            {
              aa[ci]<- max(aad) + min.diff           # assign age as max() of nodes within            
              if(aa[ci] < node.mins[ci])	aa[ci]<- node.mins[ci]
            }
       }
   }
  return (aa)
}

############################################################
# Function to assign branch lengths to all edges of tree
#   --t1 is phylo
#   --all.ages is vector of ages of terminal and internal nodes (as given by assign.ages() )
assign.brlen<- function (t1, all.ages){
  ne<- nrow(t1$edge)
  bl<- array(dim=ne)
  
  for (i in 1:ne)
    {
      anc<- t1$edge[i,1]
      dec<- t1$edge[i,2]
      bl[i]<- all.ages[anc] - all.ages[dec]
    }

  t2<- t1
  t2$edge.length<- bl
  return(t2)
}
